@@ -353,11 +353,11 @@ def histplot(
             if yerr is not None or w2 is not None:
                 if "color" not in _kwargs:
                     _kwargs["color"] = _s.get_color()
+                _kwargs["linestyle"] = "none"
                 _e = ax.errorbar(
                     _bin_centers,
                     h[i],
                     yerr=[_yerr_lo[i], _yerr_hi[i]],
-                    linestyle="none",
                     **_kwargs,
                 )
                 _eleg = ax.errorbar(
@@ -682,6 +682,9 @@ def ylow(ax=None, ylow=None):
     if ax is None:
         ax = plt.gca()
 
+    if ax.get_yaxis().get_scale() == "log":
+        return ax
+
     if ylow is None:
         # Check full figsize below 0
         bbox = Bbox.from_bounds(
